==> hy_0.10.0.orig.tar.gz: hy-0.10.0/README.md <==
Hy
==

[![Build Status](https://travis-ci.org/hylang/hy.png?branch=master)](https://travis-ci.org/hylang/hy)
[![Downloads](https://pypip.in/d/hy/badge.png)](https://crate.io/packages/hy)
[![version](https://pypip.in/v/hy/badge.png)](https://crate.io/packages/hy)
[![Coverage Status](https://coveralls.io/repos/hylang/hy/badge.png)](https://coveralls.io/r/hylang/hy)

![](https://raw.github.com/hylang/shyte/18f6925e08684b0e1f52b2cc2c803989cd62cd91/imgs/xkcd.png)

Lisp and Python should love each other. Let's make it happen. [Try it](http://try-hy.appspot.com/).

Hylarious Hacks
---------------

[Django + Lisp](https://github.com/paultag/djlisp/tree/master/djlisp)

[Python sh fun](https://twitter.com/paultag/status/314925996442796032)

[Hy IRC bot](https://github.com/hylang/hygdrop)

[miniKanren in Hy](https://github.com/algernon/adderall)

OK, so, why?
------------

Well. Python is awesome. So awesome, that we have so many tools to alter the
languge in a *core* way, but we never use them.

Why?

Well, I wrote Hy to help people realize one thing about Python:

It's really awesome.

Oh, and lisps are neat.

![](http://i.imgur.com/QbPMXTN.png)

(fan art from the one and only [doctormo](http://doctormo.deviantart.com/art/Cuddles-the-Hacker-372184766))

Project
-------

* Code: https://github.com/hylang/hy
* Docs: http://hylang.org/
* Quickstart: http://hylang.org/en/latest/quickstart.html
* Bug reports: We have no bugs! Your bugs are your own! (https://github.com/hylang/hy/issues)
* License: MIT (Expat)

==> hy_0.10.1.orig.tar.gz: hy-0.10.1/README.md <==
Hy
==

[![Build Status](https://travis-ci.org/hylang/hy.png?branch=master)](https://travis-ci.org/hylang/hy)
[![Downloads](https://pypip.in/d/hy/badge.png)](https://crate.io/packages/hy)
[![version](https://pypip.in/v/hy/badge.png)](https://crate.io/packages/hy)
[![Coverage Status](https://coveralls.io/repos/hylang/hy/badge.png)](https://coveralls.io/r/hylang/hy)

![](https://raw.github.com/hylang/shyte/18f6925e08684b0e1f52b2cc2c803989cd62cd91/imgs/xkcd.png)

Lisp and Python should love each other. Let's make it happen. [Try it](http://try-hy.appspot.com/).

Hylarious Hacks
---------------

[Django + Lisp](https://github.com/paultag/djlisp/tree/master/djlisp)

[Python sh fun](https://twitter.com/paultag/status/314925996442796032)

[Hy IRC bot](https://github.com/hylang/hygdrop)

[miniKanren in Hy](https://github.com/algernon/adderall)

OK, so, why?
------------

Well. Python is awesome. So awesome, that we have so many tools to alter the
language in a *core* way, but we never use them.

Why?

Well, I wrote Hy to help people realize one thing about Python:

It's really awesome.

Oh, and lisps are neat.

![](http://i.imgur.com/QbPMXTN.png)

(fan art from the one and only [doctormo](http://doctormo.deviantart.com/art/Cuddles-the-Hacker-372184766))

Project
-------

* Code: https://github.com/hylang/hy
* Docs: http://hylang.org/
* Quickstart: http://hylang.org/en/latest/quickstart.html
* Bug reports: We have no bugs! Your bugs are your own! (https://github.com/hylang/hy/issues)
* License: MIT (Expat)
